#!/usr/bin/python
#
# Generates a single large PNG image for a UK bounding box
# Tweak the lat/lon bounding box (ll) and image dimensions
# to get an image of arbitrary size.
#
# To use this script you must first have installed mapnik
# and imported a planet file into a Postgres DB using
# osm2pgsql.
#
# Note that mapnik renders data differently depending on
# the size of image. More detail appears as the image size
# increases but note that the text is rendered at a constant
# pixel size so will appear smaller on a large image.

from mapnik import *
import sys, os

if __name__ == "__main__":
    #try:
    #    mapfile = os.environ['MAPNIK_MAP_FILE']
    #except KeyError:
    #    mapfile = "osm.xml"

    # RequestParams auswerten
    # bbox "7.181878,50.647487,7.193478,50.654364"
    bboxSplitStringArr = sys.argv[1].split(',')
    ll = ( float(bboxSplitStringArr[0].strip()), 
           float(bboxSplitStringArr[1].strip()), 
	       float(bboxSplitStringArr[2].strip()), 
	       float(bboxSplitStringArr[3].strip()))

    # Image width
    imgx = int(sys.argv[2])

    # Image height
    imgy = int(sys.argv[3])

    # Image URI		
    map_uri = sys.argv[4]
    
    # Proj String
    proj = sys.argv[5]

    m = Map(imgx,imgy,proj)
    load_map(m,"osm_mapnik/osm.xml")
    bbox = Envelope(ll[0],ll[1],ll[2],ll[3])
    m.zoom_to_box(bbox)
    im = Image(imgx,imgy)
    render(m, im)
    view = im.view(0,0,imgx,imgy) # x,y,width,height
    view.save(map_uri,'png')
